summaryrefslogtreecommitdiffstatshomepage
path: root/src/emu/main.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/emu/main.h')
-rw-r--r--src/emu/main.h24
1 files changed, 11 insertions, 13 deletions
diff --git a/src/emu/main.h b/src/emu/main.h
index a62457a1c75..2a088a3995d 100644
--- a/src/emu/main.h
+++ b/src/emu/main.h
@@ -23,19 +23,17 @@
// CONSTANTS
//**************************************************************************
-enum
-{
- EMU_ERR_NONE = 0, /* no error */
- EMU_ERR_FAILED_VALIDITY = 1, /* failed validity checks */
- EMU_ERR_MISSING_FILES = 2, /* missing files */
- EMU_ERR_FATALERROR = 3, /* some other fatal error */
- EMU_ERR_DEVICE = 4, /* device initialization error (MESS-specific) */
- EMU_ERR_NO_SUCH_GAME = 5, /* game was specified but doesn't exist */
- EMU_ERR_INVALID_CONFIG = 6, /* some sort of error in configuration */
- EMU_ERR_IDENT_NONROMS = 7, /* identified all non-ROM files */
- EMU_ERR_IDENT_PARTIAL = 8, /* identified some files but not all */
- EMU_ERR_IDENT_NONE = 9 /* identified no files */
-};
+constexpr int EMU_ERR_NONE = 0; // no error
+constexpr int EMU_ERR_FAILED_VALIDITY = 1; // failed validity checks
+constexpr int EMU_ERR_MISSING_FILES = 2; // missing files
+constexpr int EMU_ERR_FATALERROR = 3; // some other fatal error
+constexpr int EMU_ERR_DEVICE = 4; // device initialization error
+constexpr int EMU_ERR_NO_SUCH_SYSTEM = 5; // system was specified but doesn't exist
+constexpr int EMU_ERR_INVALID_CONFIG = 6; // some sort of error in configuration
+constexpr int EMU_ERR_IDENT_NONROMS = 7; // identified all non-ROM files
+constexpr int EMU_ERR_IDENT_PARTIAL = 8; // identified some files but not all
+constexpr int EMU_ERR_IDENT_NONE = 9; // identified no files
+
//**************************************************************************
// TYPE DEFINITIONS